import{i as c,u as y}from"./index.7377ee90.js";import"./translations.d159963e.js";import{g as r}from"./runtime-dom.esm-bundler.5c3c7d72.js";import{s as h,_ as e}from"./default-i18n.20001971.js";const o="all-in-one-seo-pack",T=(g={})=>{const{returnTo:S="search-statistics"}=g,l=r(""),s=r(!1),a=r(S),i=r(!1),u=r(!1),d=()=>{s.value=!0,c().getAuthUrl({returnTo:a.value}).then(t=>{window.location=t})},p=()=>{s.value=!0,c().getReauthUrl({returnTo:a.value}).then(t=>{window.location=t})},m=()=>{s.value=!0,c().deleteAuth().then(t=>{u.value=!1,i.value=!1,t.success||(i.value=!0,l.value=t.message)}).finally(()=>{s.value=!1})},f={aioseoCanNowVerify:h(e("%1$s can now verify whether your site is correctly verified with Google Search Console and that your sitemaps have been submitted correctly. Connect with Google Search Console now to ensure your content is being added to Google as soon as possible for increased rankings.",o),"AIOSEO"),connectToGoogleSearchConsole:e("Connect to Google Search Console",o),connectToGoogleToAddSitemaps:e("Connect to Google to automatically add sitemaps and keep them in sync.",o),syncYourSiteWithGsc:e("Upgrade to Pro to unlock Search Statistics and sync your site with Google Search Console. Get valuable insights right inside your WordPress dashboard, track keyword rankings and search performance for individual posts with actionable insights to help you rank higher in search results!",o),fixSitemapErrors:e("Fix Errors",o),aioseoHasFoundSomeErrorsInSitemaps:h(e("%1$s has found some errors in sitemaps that were previously submitted to Google Search Console. Since %1$s manages your sitemaps, these additional sitemaps can be removed.",o),"AIOSEO"),thereAreSitemapsWithErrors:e("There are sitemaps with errors",o),gscFeature1:e("Google Search Console Metrics",o),gscFeature2:e("SEO Changes Performance Tracking",o),gscFeature3:e("Top Content Discovery",o),gscFeature4:e("Content Decay Tracking",o)};return{alertMessage:l,connect:d,disconnect:m,loading:s,reconnect:p,redirectToGscSettings:()=>{const n=y();window.location.href=`${n.aioseo.urls.aio.settings}&aioseo-scroll=google-search-console-settings&aioseo-highlight=google-search-console-settings#/webmaster-tools?activetool=googleSearchConsole`},returnTo:a,showAlert:i,showModal:u,strings:f}};export{T as u};
